@@ -6,15 +6,15 @@ use Database::Abstraction;
 
 =head1 NAME
 
-Genealogy::Wills::wills - database driver
+Genealogy::Wills::wills - database driver for Genealogy::Wills
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our @ISA = ('Database::Abstraction');
 
